package org.example.repository.impl;

import org.example.entity.CompanyTypeDictEntity;
import org.example.entity.CreditTypeDictEntity;
import org.example.entity.DictEntity;
import org.example.entity.UserCategoryDictEntity;
import org.example.repository.DictRepository;
import org.springframework.stereotype.Repository;

import java.util.*;

@Repository
public class DictRepositoryImpl implements DictRepository {

    private final Map<String, DictEntity> dictMap;
    private final Map<String, UserCategoryDictEntity> userCategoryDictMap;
    private final Map<String, CompanyTypeDictEntity> companyTypeDictMap;
    private final Map<String, CreditTypeDictEntity> creditTypeDictMap;

    public DictRepositoryImpl() {
        dictMap = new LinkedHashMap<>();
        dictMap.put("1", DictEntity.builder()
                .dictCode("1")
                .dictName("正常")
                .build());
        dictMap.put("2", DictEntity.builder()
                .dictCode("2")
                .dictName("禁用")
                .build());

        userCategoryDictMap = new LinkedHashMap<>();
        userCategoryDictMap.put("1", UserCategoryDictEntity.builder()
                .userCategory("1")
                .userCategoryName("企业用户")
                .build());
        userCategoryDictMap.put("2", UserCategoryDictEntity.builder()
                .userCategory("2")
                .userCategoryName("个人用户")
                .build());

        companyTypeDictMap = new LinkedHashMap<>();
        companyTypeDictMap.put("C", CompanyTypeDictEntity.builder()
                .companyType("C")
                .dictName("集团企业")
                .dictDesc("大型集团企业")
                .build());

        creditTypeDictMap = new LinkedHashMap<>();
        creditTypeDictMap.put(ck("2", "A"), CreditTypeDictEntity.builder()
                .creditType("2")
                .creditLevel("A")
                .creditTypeName("良好")
                .build());
    }

    @Override
    public List<DictEntity> getDict(DictEntity query) {
        return Optional.ofNullable(query)
                .map(DictEntity::getDictCode)
                .map(dictMap::get)
                .map(Collections::singletonList)
                .orElseGet(Collections::emptyList);
    }

    @Override
    public List<UserCategoryDictEntity> getUserCategoryDict(UserCategoryDictEntity query) {
        return Optional.ofNullable(query)
                .map(UserCategoryDictEntity::getUserCategory)
                .map(userCategoryDictMap::get)
                .map(Collections::singletonList)
                .orElseGet(Collections::emptyList);
    }

    @Override
    public List<CompanyTypeDictEntity> getCompanyTypeDict(CompanyTypeDictEntity query) {
        return Optional.ofNullable(query)
                .map(CompanyTypeDictEntity::getCompanyType)
                .map(companyTypeDictMap::get)
                .map(Collections::singletonList)
                .orElseGet(Collections::emptyList);
    }

    @Override
    public List<CreditTypeDictEntity> getCreditTypeDict(CreditTypeDictEntity query) {
        return Optional.ofNullable(query)
                .map(v -> ck(v.getCreditType(), v.getCreditLevel()))
                .map(creditTypeDictMap::get)
                .map(Collections::singletonList)
                .orElseGet(Collections::emptyList);
    }

    private static String ck(String creditType, String creditLevel) {
        return creditType + "#" + creditLevel;
    }
}
